# Lace stats

Contains component model and hyperprior specifications.

This crate contains:

- New column types and the extra data structures required for using a component
  model in lace
- Statistical utilities for MCMC
- Statistical utilities for Monte Carlo integration
- Statistical test like KS and Chi-Square
